@@ -1,7 +1,7 @@
 package App::Media::Info;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-04-06'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010;
 use strict;
@@ -23,6 +23,10 @@ $SPEC{media_info} = {
             #'x.schema.entity' => 'filename_or_url',
             'x.schema.entity' => 'filename', # temp
         },
+        backend => {
+            summary => 'Choose a specific backend',
+            schema  => ['str*', in => [qw/Mplayer Ffmpeg/]],
+        },
     },
 };
 sub media_info {
@@ -33,11 +37,17 @@ sub media_info {
     my $media = $args{media};
 
     if (@$media == 1) {
-        return Media::Info::get_media_info(media => $media->[0]);
+        return Media::Info::get_media_info(
+            media => $media->[0],
+            (backend => $args{backend}) x !!(defined $args{backend}),
+        );
     } else {
         my @res;
         for (@$media) {
-            my $res = Media::Info::get_media_info(media => $_);
+            my $res = Media::Info::get_media_info(
+                media => $_,
+                (backend => $args{backend}) x !!(defined $args{backend}),
+            );
             unless ($res->[0] == 200) {
                 warn "Can't get media info for '$_': $res->[1] ($res->[0])\n";
                 next;
@@ -63,7 +73,7 @@ App::Media::Info - Get information about media files/URLs
 
 =head1 VERSION
 
-This document describes version 0.08 of App::Media::Info (from Perl distribution Media-Info), released on 2015-09-03.
+This document describes version 0.09 of App::Media::Info (from Perl distribution Media-Info), released on 2016-04-06.
 
 =head1 FUNCTIONS
 
@@ -72,10 +82,16 @@ This document describes version 0.08 of App::Media::Info (from Perl distribution
 
 Get information about media files/URLs.
 
+This function is not exported.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<backend> => I<str>
+
+Choose a specific backend.
+
 =item * B<media>* => I<array[str]>
 
 Media files/URLs.
@@ -115,7 +131,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
