@@ -1,7 +1,7 @@
 package Media::Info;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.08'; # VERSION
+our $DATE = '2016-04-06'; # DATE
+our $VERSION = '0.09'; # VERSION
 
 use 5.010001;
 use strict;
@@ -25,12 +25,45 @@ $SPEC{get_media_info} = {
             pos     => 0,
             req     => 1,
         },
+        backend => {
+            summary => "Choose specific backend",
+            schema  => ['str*', match => '\A\w+\z'],
+        },
     },
 };
 sub get_media_info {
-    require Media::Info::Mplayer;
+    no strict 'refs';
 
-    Media::Info::Mplayer::get_media_info(@_);
+    my %args = @_;
+
+    my @backends;
+    if ($args{backend}) {
+        @backends = ($args{backend});
+    } else {
+        @backends = qw(Ffmpeg Mplayer);
+    }
+
+    # try the first backend that succeeds
+    for my $backend (@backends) {
+        my $mod;
+        my $mod_pm;
+        if ($backend =~ /\A\w+\z/) {
+            $mod    = "Media::Info::$backend";
+            $mod_pm = "Media/Info/$backend.pm";
+        } else {
+            return [400, "Invalid backend '$backend'"];
+        }
+        next unless eval { require $mod_pm; 1 };
+        my $func = \&{"$mod\::get_media_info"};
+        my $res = $func->(media => $args{media});
+        return $res unless $res->[0] == 412;
+    }
+
+    if ($args{backend}) {
+        return [412, "Backend '$args{backend}' not available, please install it first"];
+    } else {
+        return [412, "No Media::Info::* backends available, please install one"];
+    }
 }
 
 1;
@@ -48,7 +81,7 @@ Media::Info - Return information on media file/URL
 
 =head1 VERSION
 
-This document describes version 0.08 of Media::Info (from Perl distribution Media-Info), released on 2015-09-03.
+This document describes version 0.09 of Media::Info (from Perl distribution Media-Info), released on 2016-04-06.
 
 =head1 SYNOPSIS
 
@@ -77,8 +110,8 @@ Sample result:
 
 This module provides a common interface for Media::Info::* modules, which you
 can use to get information about a media file (like video, music, etc) using
-specific backends. Currently the only backend available is
-L<Media::Info::Mplayer>, so this module uses that.
+specific backends. Currently the available backends include
+L<Media::Info::Mplayer> and L<Media::Info::Ffmpeg>.
 
 =head1 FUNCTIONS
 
@@ -87,10 +120,16 @@ L<Media::Info::Mplayer>, so this module uses that.
 
 Return information on media file/URL.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
 
+=item * B<backend> => I<str>
+
+Choose specific backend.
+
 =item * B<media>* => I<str>
 
 Media file/URL.
@@ -108,13 +147,6 @@ that contains extra information.
 
 Return value:  (any)
 
-=head1 SEE ALSO
-
-L<Video::Info> - This module is first written because I couldn't install
-Video::Info. That module doesn't seem maintained (last release is in 2003 at the
-time of this writing), plus I want a per-backend namespace organization instead
-of per-format one, and a simple functional interface instead of OO interface.
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Media-Info>.
@@ -131,13 +163,20 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Video::Info> - This module is first written because I couldn't install
+Video::Info. That module doesn't seem maintained (last release is in 2003 at the
+time of this writing), plus I want a per-backend namespace organization instead
+of per-format one, and a simple functional interface instead of OO interface.
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
